// Copyright 2024 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   extensions/common/api/audio.idl
// by tools/json_schema_compiler.
// DO NOT EDIT.

#include "extensions/common/api/audio.h"

#include <memory>
#include <ostream>
#include <string>
#include <utility>
#include <vector>

#include "base/check.h"
#include "base/check_op.h"
#include "base/notreached.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/utf_string_conversions.h"
#include "base/values.h"
#include "tools/json_schema_compiler/util.h"

using base::UTF8ToUTF16;

namespace extensions {
namespace api {
namespace audio {
//
// Types
//

const char* ToString(StreamType enum_param) {
  switch (enum_param) {
    case STREAM_TYPE_INPUT:
      return "INPUT";
    case STREAM_TYPE_OUTPUT:
      return "OUTPUT";
    case STREAM_TYPE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

StreamType ParseStreamType(const std::string& enum_string) {
  if (enum_string == "INPUT")
    return STREAM_TYPE_INPUT;
  if (enum_string == "OUTPUT")
    return STREAM_TYPE_OUTPUT;
  return STREAM_TYPE_NONE;
}


const char* ToString(DeviceType enum_param) {
  switch (enum_param) {
    case DEVICE_TYPE_HEADPHONE:
      return "HEADPHONE";
    case DEVICE_TYPE_MIC:
      return "MIC";
    case DEVICE_TYPE_USB:
      return "USB";
    case DEVICE_TYPE_BLUETOOTH:
      return "BLUETOOTH";
    case DEVICE_TYPE_HDMI:
      return "HDMI";
    case DEVICE_TYPE_INTERNAL_SPEAKER:
      return "INTERNAL_SPEAKER";
    case DEVICE_TYPE_INTERNAL_MIC:
      return "INTERNAL_MIC";
    case DEVICE_TYPE_FRONT_MIC:
      return "FRONT_MIC";
    case DEVICE_TYPE_REAR_MIC:
      return "REAR_MIC";
    case DEVICE_TYPE_KEYBOARD_MIC:
      return "KEYBOARD_MIC";
    case DEVICE_TYPE_HOTWORD:
      return "HOTWORD";
    case DEVICE_TYPE_LINEOUT:
      return "LINEOUT";
    case DEVICE_TYPE_POST_MIX_LOOPBACK:
      return "POST_MIX_LOOPBACK";
    case DEVICE_TYPE_POST_DSP_LOOPBACK:
      return "POST_DSP_LOOPBACK";
    case DEVICE_TYPE_ALSA_LOOPBACK:
      return "ALSA_LOOPBACK";
    case DEVICE_TYPE_OTHER:
      return "OTHER";
    case DEVICE_TYPE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

DeviceType ParseDeviceType(const std::string& enum_string) {
  if (enum_string == "HEADPHONE")
    return DEVICE_TYPE_HEADPHONE;
  if (enum_string == "MIC")
    return DEVICE_TYPE_MIC;
  if (enum_string == "USB")
    return DEVICE_TYPE_USB;
  if (enum_string == "BLUETOOTH")
    return DEVICE_TYPE_BLUETOOTH;
  if (enum_string == "HDMI")
    return DEVICE_TYPE_HDMI;
  if (enum_string == "INTERNAL_SPEAKER")
    return DEVICE_TYPE_INTERNAL_SPEAKER;
  if (enum_string == "INTERNAL_MIC")
    return DEVICE_TYPE_INTERNAL_MIC;
  if (enum_string == "FRONT_MIC")
    return DEVICE_TYPE_FRONT_MIC;
  if (enum_string == "REAR_MIC")
    return DEVICE_TYPE_REAR_MIC;
  if (enum_string == "KEYBOARD_MIC")
    return DEVICE_TYPE_KEYBOARD_MIC;
  if (enum_string == "HOTWORD")
    return DEVICE_TYPE_HOTWORD;
  if (enum_string == "LINEOUT")
    return DEVICE_TYPE_LINEOUT;
  if (enum_string == "POST_MIX_LOOPBACK")
    return DEVICE_TYPE_POST_MIX_LOOPBACK;
  if (enum_string == "POST_DSP_LOOPBACK")
    return DEVICE_TYPE_POST_DSP_LOOPBACK;
  if (enum_string == "ALSA_LOOPBACK")
    return DEVICE_TYPE_ALSA_LOOPBACK;
  if (enum_string == "OTHER")
    return DEVICE_TYPE_OTHER;
  return DEVICE_TYPE_NONE;
}


AudioDeviceInfo::AudioDeviceInfo()
: stream_type(STREAM_TYPE_NONE),
device_type(DEVICE_TYPE_NONE),
is_active(false),
level(0) {}

AudioDeviceInfo::~AudioDeviceInfo() = default;
AudioDeviceInfo::AudioDeviceInfo(AudioDeviceInfo&& rhs) = default;
AudioDeviceInfo& AudioDeviceInfo::operator=(AudioDeviceInfo&& rhs) = default;
// static
bool AudioDeviceInfo::Populate(
    const base::Value& value, AudioDeviceInfo* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* id_value = dict.Find("id");
  if (!id_value) {
    return false;
  }
  {
    auto* temp = (*id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->id = *temp;
  }

  const base::Value* stream_type_value = dict.Find("streamType");
  if (!stream_type_value) {
    return false;
  }
  {
    const std::string* stream_type_as_string = (*stream_type_value).GetIfString();
    if (!stream_type_as_string) {
      return false;
    }
    out->stream_type = ParseStreamType(*stream_type_as_string);
    if (out->stream_type == STREAM_TYPE_NONE) {
      return false;
    }
  }

  const base::Value* device_type_value = dict.Find("deviceType");
  if (!device_type_value) {
    return false;
  }
  {
    const std::string* device_type_as_string = (*device_type_value).GetIfString();
    if (!device_type_as_string) {
      return false;
    }
    out->device_type = ParseDeviceType(*device_type_as_string);
    if (out->device_type == DEVICE_TYPE_NONE) {
      return false;
    }
  }

  const base::Value* display_name_value = dict.Find("displayName");
  if (!display_name_value) {
    return false;
  }
  {
    auto* temp = (*display_name_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->display_name = *temp;
  }

  const base::Value* device_name_value = dict.Find("deviceName");
  if (!device_name_value) {
    return false;
  }
  {
    auto* temp = (*device_name_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->device_name = *temp;
  }

  const base::Value* is_active_value = dict.Find("isActive");
  if (!is_active_value) {
    return false;
  }
  {
    auto temp = (*is_active_value).GetIfBool();
    if (!temp.has_value()) {
      return false;
    }
    out->is_active = *temp;
  }

  const base::Value* level_value = dict.Find("level");
  if (!level_value) {
    return false;
  }
  {
    auto temp = (*level_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->level = *temp;
  }

  const base::Value* stable_device_id_value = dict.Find("stableDeviceId");
  if (stable_device_id_value) {
    {
      auto* temp = (*stable_device_id_value).GetIfString();
      if (!temp) {
        out->stable_device_id = absl::nullopt;
        return false;
      }
      out->stable_device_id = *temp;
    }
  }

  return true;
}

// static
std::unique_ptr<AudioDeviceInfo> AudioDeviceInfo::FromValue(const base::Value& value) {
  auto out = std::make_unique<AudioDeviceInfo>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict AudioDeviceInfo::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("id", this->id);

  to_value_result.Set("streamType", audio::ToString(this->stream_type));

  to_value_result.Set("deviceType", audio::ToString(this->device_type));

  to_value_result.Set("displayName", this->display_name);

  to_value_result.Set("deviceName", this->device_name);

  to_value_result.Set("isActive", this->is_active);

  to_value_result.Set("level", this->level);

  if (this->stable_device_id) {
    to_value_result.Set("stableDeviceId", *this->stable_device_id);

  }

  return to_value_result;
}


DeviceFilter::DeviceFilter()
 {}

DeviceFilter::~DeviceFilter() = default;
DeviceFilter::DeviceFilter(DeviceFilter&& rhs) = default;
DeviceFilter& DeviceFilter::operator=(DeviceFilter&& rhs) = default;
// static
bool DeviceFilter::Populate(
    const base::Value& value, DeviceFilter* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* stream_types_value = dict.Find("streamTypes");
  if (stream_types_value) {
    {
      if (!(*stream_types_value).is_list()) {
        return false;
      }
      else {
        out->stream_types.emplace();
        for (const auto& it : ((*stream_types_value)).GetList()) {
          StreamType tmp;
          const std::string* stream_type_as_string = (it).GetIfString();
          if (!stream_type_as_string) {
            return false;
          }
          tmp = ParseStreamType(*stream_type_as_string);
          if (tmp == STREAM_TYPE_NONE) {
            return false;
          }
          out->stream_types->push_back(tmp);
        }
      }
    }
  }

  const base::Value* is_active_value = dict.Find("isActive");
  if (is_active_value) {
    {
      auto temp = (*is_active_value).GetIfBool();
      if (!temp.has_value()) {
        out->is_active = absl::nullopt;
        return false;
      }
      out->is_active = *temp;
    }
  }

  return true;
}

// static
std::unique_ptr<DeviceFilter> DeviceFilter::FromValue(const base::Value& value) {
  auto out = std::make_unique<DeviceFilter>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict DeviceFilter::ToValue() const {
  base::Value::Dict to_value_result;

  if (this->stream_types) {
    {
      std::vector<std::string> streamTypes_list;
      for (const auto& it : *(this->stream_types)) {
      streamTypes_list.push_back(audio::ToString(it));
    }
    to_value_result.Set("streamTypes", json_schema_compiler::util::CreateValueFromArray(streamTypes_list));
    }

  }
  if (this->is_active) {
    to_value_result.Set("isActive", *this->is_active);

  }

  return to_value_result;
}


DeviceProperties::DeviceProperties()
 {}

DeviceProperties::~DeviceProperties() = default;
DeviceProperties::DeviceProperties(DeviceProperties&& rhs) = default;
DeviceProperties& DeviceProperties::operator=(DeviceProperties&& rhs) = default;
// static
bool DeviceProperties::Populate(
    const base::Value& value, DeviceProperties* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* level_value = dict.Find("level");
  if (level_value) {
    {
      auto temp = (*level_value).GetIfInt();
      if (!temp.has_value()) {
        out->level = absl::nullopt;
        return false;
      }
      out->level = *temp;
    }
  }

  return true;
}

// static
std::unique_ptr<DeviceProperties> DeviceProperties::FromValue(const base::Value& value) {
  auto out = std::make_unique<DeviceProperties>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict DeviceProperties::ToValue() const {
  base::Value::Dict to_value_result;

  if (this->level) {
    to_value_result.Set("level", *this->level);

  }

  return to_value_result;
}


DeviceIdLists::DeviceIdLists()
 {}

DeviceIdLists::~DeviceIdLists() = default;
DeviceIdLists::DeviceIdLists(DeviceIdLists&& rhs) = default;
DeviceIdLists& DeviceIdLists::operator=(DeviceIdLists&& rhs) = default;
// static
bool DeviceIdLists::Populate(
    const base::Value& value, DeviceIdLists* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* input_value = dict.Find("input");
  if (input_value) {
    {
      if (!(*input_value).is_list()) {
        return false;
      }
      else {
        if (!json_schema_compiler::util::PopulateOptionalArrayFromList((*input_value).GetList(), &out->input)) {
          return false;
        }
      }
    }
  }

  const base::Value* output_value = dict.Find("output");
  if (output_value) {
    {
      if (!(*output_value).is_list()) {
        return false;
      }
      else {
        if (!json_schema_compiler::util::PopulateOptionalArrayFromList((*output_value).GetList(), &out->output)) {
          return false;
        }
      }
    }
  }

  return true;
}

// static
std::unique_ptr<DeviceIdLists> DeviceIdLists::FromValue(const base::Value& value) {
  auto out = std::make_unique<DeviceIdLists>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict DeviceIdLists::ToValue() const {
  base::Value::Dict to_value_result;

  if (this->input) {
    to_value_result.Set("input", json_schema_compiler::util::CreateValueFromArray(*this->input));

  }
  if (this->output) {
    to_value_result.Set("output", json_schema_compiler::util::CreateValueFromArray(*this->output));

  }

  return to_value_result;
}


MuteChangedEvent::MuteChangedEvent()
: stream_type(STREAM_TYPE_NONE),
is_muted(false) {}

MuteChangedEvent::~MuteChangedEvent() = default;
MuteChangedEvent::MuteChangedEvent(MuteChangedEvent&& rhs) = default;
MuteChangedEvent& MuteChangedEvent::operator=(MuteChangedEvent&& rhs) = default;
// static
bool MuteChangedEvent::Populate(
    const base::Value& value, MuteChangedEvent* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* stream_type_value = dict.Find("streamType");
  if (!stream_type_value) {
    return false;
  }
  {
    const std::string* stream_type_as_string = (*stream_type_value).GetIfString();
    if (!stream_type_as_string) {
      return false;
    }
    out->stream_type = ParseStreamType(*stream_type_as_string);
    if (out->stream_type == STREAM_TYPE_NONE) {
      return false;
    }
  }

  const base::Value* is_muted_value = dict.Find("isMuted");
  if (!is_muted_value) {
    return false;
  }
  {
    auto temp = (*is_muted_value).GetIfBool();
    if (!temp.has_value()) {
      return false;
    }
    out->is_muted = *temp;
  }

  return true;
}

// static
std::unique_ptr<MuteChangedEvent> MuteChangedEvent::FromValue(const base::Value& value) {
  auto out = std::make_unique<MuteChangedEvent>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict MuteChangedEvent::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("streamType", audio::ToString(this->stream_type));

  to_value_result.Set("isMuted", this->is_muted);


  return to_value_result;
}


LevelChangedEvent::LevelChangedEvent()
: level(0) {}

LevelChangedEvent::~LevelChangedEvent() = default;
LevelChangedEvent::LevelChangedEvent(LevelChangedEvent&& rhs) = default;
LevelChangedEvent& LevelChangedEvent::operator=(LevelChangedEvent&& rhs) = default;
// static
bool LevelChangedEvent::Populate(
    const base::Value& value, LevelChangedEvent* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* device_id_value = dict.Find("deviceId");
  if (!device_id_value) {
    return false;
  }
  {
    auto* temp = (*device_id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->device_id = *temp;
  }

  const base::Value* level_value = dict.Find("level");
  if (!level_value) {
    return false;
  }
  {
    auto temp = (*level_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->level = *temp;
  }

  return true;
}

// static
std::unique_ptr<LevelChangedEvent> LevelChangedEvent::FromValue(const base::Value& value) {
  auto out = std::make_unique<LevelChangedEvent>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict LevelChangedEvent::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("deviceId", this->device_id);

  to_value_result.Set("level", this->level);


  return to_value_result;
}



//
// Functions
//

namespace GetDevices {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() > 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& filter_value = args[0];
    {
      if (!filter_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      else {
        DeviceFilter temp;
        if (!DeviceFilter::Populate(filter_value, &temp))
          return std::unique_ptr<Params>();
        params->filter = std::move(temp);
      }
    }
  }

  return params;
}


base::Value::List Results::Create(const std::vector<AudioDeviceInfo>& devices) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(json_schema_compiler::util::CreateValueFromArray(devices));

  return create_results;
}
}  // namespace GetDevices

namespace SetActiveDevices {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& ids_value = args[0];
    {
      if (!ids_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!DeviceIdLists::Populate(ids_value, &params->ids)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create() {
  base::Value::List create_results;

  return create_results;
}
}  // namespace SetActiveDevices

namespace SetProperties {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 2) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& id_value = args[0];
    {
      auto* temp = id_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->id = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  if (1 < args.size() &&
      !args[1].is_none()) {
    const base::Value& properties_value = args[1];
    {
      if (!properties_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!DeviceProperties::Populate(properties_value, &params->properties)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create() {
  base::Value::List create_results;

  return create_results;
}
}  // namespace SetProperties

namespace GetMute {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& stream_type_value = args[0];
    {
      const std::string* stream_type_as_string = stream_type_value.GetIfString();
      if (!stream_type_as_string) {
        return std::unique_ptr<Params>();
      }
      params->stream_type = ParseStreamType(*stream_type_as_string);
      if (params->stream_type == STREAM_TYPE_NONE) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create(bool value) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(value);

  return create_results;
}
}  // namespace GetMute

namespace SetMute {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 2) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& stream_type_value = args[0];
    {
      const std::string* stream_type_as_string = stream_type_value.GetIfString();
      if (!stream_type_as_string) {
        return std::unique_ptr<Params>();
      }
      params->stream_type = ParseStreamType(*stream_type_as_string);
      if (params->stream_type == STREAM_TYPE_NONE) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  if (1 < args.size() &&
      !args[1].is_none()) {
    const base::Value& is_muted_value = args[1];
    {
      auto temp = is_muted_value.GetIfBool();
      if (!temp.has_value()) {
        return std::unique_ptr<Params>();
      }
      params->is_muted = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create() {
  base::Value::List create_results;

  return create_results;
}
}  // namespace SetMute

//
// Events
//

namespace OnLevelChanged {

const char kEventName[] = "audio.onLevelChanged";

base::Value::List Create(const LevelChangedEvent& event) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((event).ToValue());

  return create_results;
}

}  // namespace OnLevelChanged

namespace OnMuteChanged {

const char kEventName[] = "audio.onMuteChanged";

base::Value::List Create(const MuteChangedEvent& event) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((event).ToValue());

  return create_results;
}

}  // namespace OnMuteChanged

namespace OnDeviceListChanged {

const char kEventName[] = "audio.onDeviceListChanged";

base::Value::List Create(const std::vector<AudioDeviceInfo>& devices) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(json_schema_compiler::util::CreateValueFromArray(devices));

  return create_results;
}

}  // namespace OnDeviceListChanged

}  // namespace audio
}  // namespace api
}  // namespace extensions

